garak.buffs
===============

.. toctree::
   :maxdepth: 2

   garak.buffs
   garak.buffs.base
   garak.buffs.encoding
   garak.buffs.low_resource_languages
   garak.buffs.lowercase
   garak.buffs.paraphrase
